audeer
======

.. automodule:: audeer
 
basename_wo_ext
---------------

.. autofunction:: basename_wo_ext

common_directory
----------------

.. autofunction:: common_directory

config
------

.. autoclass:: config
    :members:

create_archive
--------------

.. autofunction:: create_archive

deprecated
----------

.. autofunction:: deprecated

deprecated_default_value
------------------------

.. autofunction:: deprecated_default_value

deprecated_keyword_argument
---------------------------

.. autofunction:: deprecated_keyword_argument

download_url
------------

.. autofunction:: download_url

extract_archive
---------------

.. autofunction:: extract_archive

extract_archives
----------------

.. autofunction:: extract_archives

file_extension
--------------

.. autofunction:: file_extension

flatten_list
------------

.. autofunction:: flatten_list

format_display_message
----------------------

.. autofunction:: format_display_message

freeze_requirements
-------------------

.. autofunction:: freeze_requirements

git_repo_tags
-------------

.. autofunction:: git_repo_tags

git_repo_version
----------------

.. autofunction:: git_repo_version

is_semantic_version
-------------------

.. autofunction:: is_semantic_version

is_uid
------

.. autofunction:: is_uid

list_dir_names
---------------

.. autofunction:: list_dir_names

list_file_names
---------------

.. autofunction:: list_file_names

mkdir
-----

.. autofunction:: mkdir

progress_bar
------------

.. autofunction:: progress_bar

replace_file_extension
----------------------

.. autofunction:: replace_file_extension

rmdir
-----

.. autofunction:: rmdir

run_tasks
---------

.. autofunction:: run_tasks

safe_path
---------

.. autofunction:: safe_path

sort_versions
-------------

.. autofunction:: sort_versions

to_list
-------

.. autofunction:: to_list

uid
---

.. autofunction:: uid
